@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 
+import random
 import sys
 from fnmatch import fnmatch
 from pkg_resources import iter_entry_points
@@ -79,22 +80,35 @@ class All(object):
                     _files.append(f)
         data['files'] = _files
         
-class Sort(object):
+class Sort(FormatterBase):
     """
     determines how to sort the files in a directory; 
     right now only by case-insensitive alphabetically
     * reverse : reverse the order of the sorting
     """
+    defaults = {'order': 'name'}
+    
     def __init__(self, pattern):
-        self.args = [i.strip() for i in pattern.split(',')]
+        FormatterBase.__init__(self, pattern)
+        self.orders = {'name': self.name,
+                       'random': self.random,
+                       }
     
     def __call__(self, request, data):
 
-        data['files'] = sorted(data['files'], key=lambda x: x['name'].lower())
+        sort = self.orders.get(request.GET.get('order', self.order), self.name)
+        data['files'] = sort(data['files'])
 
         if 'reverse' in self.args:
             data['files'] = list(reversed(data['files']))
-    
+
+    def name(self, files):
+        return sorted(files, key=lambda x: x['name'].lower())
+
+    def random(self, files):
+        random.shuffle(files)
+        return files
+
 
 class Order(object):
     """
@@ -187,8 +201,8 @@ class Links(FormatterBase):
                 links = links.split(self.separator)
                 assert min(['=' in link for link in links])
                 links = [ link.split('=', 1) for link in links ]
-                f['links'] = [ { 'text': text, 'link': link }
-                             for text, link in links ]
+                f['links'] = [{ 'text': text, 'link': link }
+                              for text, link in links]
 
 
 class Up(object):
